@@ -7,7 +7,6 @@ from jax.lax import create_token
 
 from jax.interpreters import mlir
 import jaxlib.mlir.ir as ir
-from jaxlib.mhlo_helpers import custom_call
 
 from ..utils import (
     HashableMPIType,
@@ -20,6 +19,7 @@ from ..utils import (
     get_default_layouts,
     effect,
 )
+from ..jax_compat import hlo_custom_call, token_type
 from ..decorators import translation_rule_cpu, translation_rule_gpu
 from ..validation import enforce_types
 from ..comm import get_default_comm
@@ -117,7 +117,7 @@ def mpi_scatter_xla_encode_cpu(ctx, x, token, root, comm):
 
     out_types = [
         ir.RankedTensorType.get(dims, dtype),
-        *mlir.token_type(),
+        *token_type(),
     ]
 
     operands = (
@@ -133,7 +133,7 @@ def mpi_scatter_xla_encode_cpu(ctx, x, token, root, comm):
         token,
     )
 
-    return custom_call(
+    return hlo_custom_call(
         b"mpi_scatter",
         out_types=out_types,
         operands=operands,
@@ -166,7 +166,7 @@ def mpi_scatter_xla_encode_gpu(ctx, x, token, root, comm):
 
     out_types = [
         ir.RankedTensorType.get(dims, dtype),
-        *mlir.token_type(),
+        *token_type(),
     ]
 
     operands = (
@@ -185,7 +185,7 @@ def mpi_scatter_xla_encode_gpu(ctx, x, token, root, comm):
         to_mpi_handle(comm),
     )
 
-    return custom_call(
+    return hlo_custom_call(
         b"mpi_scatter",
         out_types=out_types,
         operands=operands,
