@@ -8,6 +8,9 @@ from jax.interpreters import xla, mlir
 import jaxlib.mlir.ir as ir
 from jaxlib.mlir.dialects import mhlo
 from jax._src.lax import control_flow as lcf
+import jax._src.custom_derivatives as custom_derivatives
+
+from .jax_compat import token_type
 
 
 class MPIEffect:
@@ -19,6 +22,9 @@ class MPIEffect:
 effect = MPIEffect()
 mlir.lowerable_effects.add(effect)
 lcf.allowed_effects.add(effect)
+# Effects must be added to the allow_effects list in order to work within
+# custom_vjp. See google/jax#11916
+custom_derivatives.allowed_effects.add(effect)
 
 
 def default_primitive_impl(primitive):
@@ -37,7 +43,7 @@ def as_mhlo_constant(val, dtype):
 
 
 def get_default_layouts(operands, order="c"):
-    (token_type,) = mlir.token_type()
+    (token,) = token_type()
     layouts = []
 
     if order == "c":
@@ -49,7 +55,7 @@ def get_default_layouts(operands, order="c"):
 
     for op in operands:
         if isinstance(op, (ir.Value)):
-            if op.type == token_type:
+            if op.type == token:
                 layouts.append(())
             else:
                 tensor_type = ir.RankedTensorType(op.type)
@@ -58,7 +64,7 @@ def get_default_layouts(operands, order="c"):
         elif isinstance(op, ir.RankedTensorType):
             layouts.append(default_layout(op))
 
-        elif op == token_type:
+        elif op == token:
             layouts.append(())
 
         else:
